<?php

use Illuminate\Foundation\Testing\WithoutMiddleware;
use Illuminate\Foundation\Testing\DatabaseMigrations;
use Illuminate\Foundation\Testing\DatabaseTransactions;


class ResumeControllerTest extends TestCase
{
    use DatabaseTransactions;
    use WithoutMiddleware;

    protected $company;
    protected $subjob;
    protected $tambon;
    protected $resume;
    protected $job;
    protected $viewerLog;
    protected $ctr;

    protected function setup()
    {

        parent::setup();

        $this->company = factory(App\Company::class)->create()->fresh();
    
        $this->tambon = factory(App\Tambon::class)
                ->create([
                    'T_CODE' => '2',
                    'P_CODE' => '6'
                ])->fresh();

        $this->resume = factory(App\Resume::class)
                ->create(['TAMBONCODE' => '$tambon->T_CODE'])->fresh();

        $this->createJob();

        $this->viewerLog = factory(App\ViewerLog::class)
                ->create([
                    'JobCode'       => $this->job->RunningNumber, 
                    'CompanyCode' => $this->company->RunningNumber,
                    'Code'        => $this->resume->RunningNumber,
                ])->fresh();

        $this->ctr = factory(App\CTR::class)
                ->create(['JobCode' => $this->job->RunningNumber])->fresh();
    }

    protected function createJob()
    {
        $this->subjob = factory(App\SubJobType::class)->create()->fresh();

        $this->job = factory(App\Job::class)
                ->create([
                    'CompanyCode' => $this->company->RunningNumber,
                    'SubJobType' => $this->subjob->Code,
                    'TAMBONCODE' => $this->tambon->T_CODE
                ])->fresh(); 
    }

    public function testShow_ResumeDetail()
    {

       $app = factory(App\ApplicationDataAnalyzer::class)
            ->create([
                'JobCode'    => $this->job->RunningNumber,
                'ResumeCode' => $this->resume->RunningNumber,
                'CompanyCode' => $this->company->RunningNumber,
            ])->fresh();

        $jobs = $this->company
            ->jobs()
            ->online()
            ->get();

        $bindings = [
            ['company' => $this->company],
            ['jobs'    => $jobs],
            ['resume'  => $this->resume],
            
         ];

        $this->get('/company/' . $this->company->RunningNumber . '/resume/' . $this->resume->RunningNumber)
            ->assertViewHasAll($bindings);
    }
    public function testResumeContainer()
    {

        $jobs = $this->company
            ->jobs()
            ->online()
            ->get();

        $active = 'a' . $this->job->RunningNumber;


        $bindings = [
            ['company' => $this->company],
            ['jobs'    => $jobs],
            ['job'  => $this->job],
            ['active'  => $active],
         ];

        $this->get('/company/' . $this->company->RunningNumber . '/job/' . $this->job->RunningNumber . '/resumes')
            ->assertViewHasAll($bindings);
    }

    public function testResumeList()
    {
       
        $action = $this->viewerLog->Action;

        $resumes = $this->viewerLog->with('resumes')
            ->ofJobCode($this->job->RunningNumber)
            ->ofPreviousDay(15)
            ->ofAction($action)
            ->orderBy('CreateDate', 'DESC')
            ->paginate(20);

       $expact = ['html' => View::make(
            'companyHR.resumesList', 
            [ 
                'resumes' => $resumes,
                'action'  => $action,
                'company' => $this->company->RunningNumber,
            ]
        )->render()];

        $this->get('/company/' . $this->company->RunningNumber . '/job/' . $this->job->RunningNumber . '/' . $this->viewerLog->Action)
             ->seeJsonEquals($expact);
    }

     public function testGetprovince_JobDetail()
    {  
       $province_name = $this->tambon->ofProvince($this->tambon->P_CODE)->first()->PROVINCE_THAI;

        
        
        $expect = array('province' => $province_name);

        $this->get('/recommend/'. $this->tambon->P_CODE)->seeJsonEquals($expect);
    }


    public function testGenChart()
    {
        $app = factory(App\ApplicationDataAnalyzer::class)
            ->create([
                'ResumeCode' => $this->resume->RunningNumber,
                'JobCode'    => $this->job->RunningNumber,
                'CompanyCode' => $this->company->RunningNumber,
            ])->fresh();

        $chart = $app->select( DB::raw('count(*) as counter,JobType'))
            ->ofPreviousDay(15)
            ->ofResumeCode($this->resume->RunningNumber)
            ->groupBy('JobType')
            ->get();


        $expect = ['chart' => $chart->toArray()];

        $this->get('/resume/' . $this->resume->RunningNumber . '/genChart')
        ->seeJsonEquals($expect);

    }

    public function testApplyChart()
    {
        $app = factory(App\ApplicationDataAnalyzer::class)
        ->create([
            'JobCode'    => $this->job->RunningNumber,
            'ResumeCode' => $this->resume->RunningNumber,
        ])->fresh();

        $applyers = $app->ofPreviousDay(15)
            ->where('JobCode', $this->job->RunningNumber)
            ->with('Resume')
            ->get();

        $maleAge16to20 =0;
        $maleAge21to25 =0;
        $maleAge26to30 =0;
        $maleAge31to35 =0;
        $maleAge36to40 =0;
        $maleAge41to45 =0;
        $maleAge46to50 =0;
        $maleAge51to55 =0;
        $maleAge56to60 =0;

        $femaleAge16to20 =0;
        $femaleAge21to25 =0;
        $femaleAge26to30 =0;
        $femaleAge31to35 =0;
        $femaleAge36to40 =0;
        $femaleAge41to45 =0;
        $femaleAge46to50 =0;
        $femaleAge51to55 =0;
        $femaleAge56to60 =0;

        foreach ($applyers as $applyer) {
            if($applyer->resume->Gender == "ช"){
                if(Carbon::parse($applyer->resume->DOB)->age >= 16 && Carbon::parse($applyer->resume->DOB)->age <= 20 ){
                    $maleAge16to20++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 21 && Carbon::parse($applyer->resume->DOB)->age <= 25 ){
                    $maleAge21to25++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 26 && Carbon::parse($applyer->resume->DOB)->age <= 30 ){
                    $maleAge26to30++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 31 && Carbon::parse($applyer->resume->DOB)->age <= 35 ){
                    $maleAge31to35++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 36 && Carbon::parse($applyer->resume->DOB)->age <= 40 ){
                    $maleAge36to40++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 41 && Carbon::parse($applyer->resume->DOB)->age <= 45 ){
                    $maleAge41to45++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 46 && Carbon::parse($applyer->resume->DOB)->age <= 50 ){
                    $maleAge46to50++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 51 && Carbon::parse($applyer->resume->DOB)->age <= 55 ){
                    $maleAge51to55++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 56 && Carbon::parse($applyer->resume->DOB)->age <= 60 ){
                    $maleAge56to60++;
                }
            }
            elseif($applyer->resume->Gender == "ญ"){
                if(Carbon::parse($applyer->resume->DOB)->age >= 16 && Carbon::parse($applyer->resume->DOB)->age <= 20 ){
                    $femaleAge16to20++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 21 && Carbon::parse($applyer->resume->DOB)->age <= 25 ){
                    $femaleAge21to25++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 26 && Carbon::parse($applyer->resume->DOB)->age <= 30 ){
                    $femaleAge26to30++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 31 && Carbon::parse($applyer->resume->DOB)->age <= 35 ){
                    $femaleAge31to35++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 36 && Carbon::parse($applyer->resume->DOB)->age <= 40 ){
                    $femaleAge36to40++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 41 && Carbon::parse($applyer->resume->DOB)->age <= 45 ){
                    $femaleAge41to45++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 46 && Carbon::parse($applyer->resume->DOB)->age <= 50 ){
                    $femaleAge46to50++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 51 && Carbon::parse($applyer->resume->DOB)->age <= 55 ){
                    $femaleAge51to55++;
                }
                if(Carbon::parse($applyer->resume->DOB)->age >= 56 && Carbon::parse($applyer->resume->DOB)->age <= 60){
                    $femaleAge56to60++;
                }
            }
        }

        $bindings = [
            [
                "Age"=>"16-20",
                "Male"=>$maleAge16to20,
                "Female"=>$femaleAge16to20,
            ],
            [
                "Age"=>"21-25",
                "Male"=>$maleAge21to25,
                "Female"=>$femaleAge21to25,
            ],
            [
                "Age"=>"26-30",
                "Male"=>$maleAge26to30,
                "Female"=>$femaleAge26to30,
            ],
            [
                "Age"=>"31-35",
                "Male"=>$maleAge31to35,
                "Female"=>$femaleAge31to35,
            ],
            [
                "Age"=>"36-40",
                "Male"=>$maleAge36to40,
                "Female"=>$femaleAge36to40,
            ],
            [
                "Age"=>"41-45",
                "Male"=>$maleAge41to45,
                "Female"=>$femaleAge41to45,
            ],
            [
                "Age"=>"46-50",
                "Male"=>$maleAge46to50,
                "Female"=>$femaleAge46to50,
            ],
            [
                "Age"=>"51-55",
                "Male"=>$maleAge51to55,
                "Female"=>$femaleAge51to55,
            ],
            [
                "Age"=>"56-60",
                "Male"=>$maleAge56to60,
                "Female"=>$femaleAge56to60,
            ],
        ];

        $expect = array('result' => $bindings);
             

        $this->get('/job/' . $this->job->RunningNumber . '/genChart')
        ->seeJsonEquals($expect);

    }
}